@@ -39,8 +39,8 @@
 #include <type_traits>
 #include <typeindex>
 
-#include <cereal/macros.hpp>
-#include <cereal/access.hpp>
+#include "cereal/macros.hpp"
+#include "cereal/access.hpp"
 
 namespace cereal
 {
@@ -868,6 +868,60 @@ namespace cereal
     // ######################################################################
     #undef CEREAL_MAKE_HAS_NON_MEMBER_LOAD_MINIMAL_TEST
 
+    // ######################################################################
+    //! Member load and construct check
+    template<typename T, typename A>
+    struct has_member_load_and_construct : std::integral_constant<bool,
+      std::is_same<decltype( access::load_and_construct<T>( std::declval<A&>(), std::declval< ::cereal::construct<T>&>() ) ), void>::value>
+    { };
+
+    // ######################################################################
+    //! Member load and construct check (versioned)
+    template<typename T, typename A>
+    struct has_member_versioned_load_and_construct : std::integral_constant<bool,
+      std::is_same<decltype( access::load_and_construct<T>( std::declval<A&>(), std::declval< ::cereal::construct<T>&>(), 0 ) ), void>::value>
+    { };
+
+    // ######################################################################
+    //! Creates a test for whether a non-member load_and_construct specialization exists
+    /*! This creates a class derived from std::integral_constant that will be true if
+        the type has the proper non-member function for the given archive. */
+    #define CEREAL_MAKE_HAS_NON_MEMBER_LOAD_AND_CONSTRUCT_TEST(test_name, versioned)                                            \
+    namespace detail                                                                                                            \
+    {                                                                                                                           \
+      template <class T, class A>                                                                                               \
+      struct has_non_member_##test_name##_impl                                                                                  \
+      {                                                                                                                         \
+        template <class TT, class AA>                                                                                           \
+        static auto test(int) -> decltype( LoadAndConstruct<TT>::load_and_construct(                                            \
+                                           std::declval<AA&>(), std::declval< ::cereal::construct<TT>&>() versioned ), yes());  \
+        template <class, class>                                                                                                 \
+        static no test( ... );                                                                                                  \
+        static const bool value = std::is_same<decltype( test<T, A>( 0 ) ), yes>::value;                                        \
+      };                                                                                                                        \
+    } /* end namespace detail */                                                                                                \
+    template <class T, class A>                                                                                                 \
+    struct has_non_member_##test_name : std::integral_constant<bool, detail::has_non_member_##test_name##_impl<T, A>::value> {};
+
+    // ######################################################################
+    //! Non member load and construct check
+    CEREAL_MAKE_HAS_NON_MEMBER_LOAD_AND_CONSTRUCT_TEST(load_and_construct, )
+
+    // ######################################################################
+    //! Non member load and construct check (versioned)
+    CEREAL_MAKE_HAS_NON_MEMBER_LOAD_AND_CONSTRUCT_TEST(versioned_load_and_construct, CEREAL_MAKE_VERSIONED_TEST)
+
+    // ######################################################################
+    //! Has either a member or non member load and construct
+    template<typename T, typename A>
+    struct has_load_and_construct : std::integral_constant<bool,
+      has_member_load_and_construct<T, A>::value || has_non_member_load_and_construct<T, A>::value ||
+      has_member_versioned_load_and_construct<T, A>::value || has_non_member_versioned_load_and_construct<T, A>::value>
+    { };
+
+    // ######################################################################
+    #undef CEREAL_MAKE_HAS_NON_MEMBER_LOAD_AND_CONSTRUCT_TEST
+
     // ######################################################################
     // End of serialization existence tests
     #undef CEREAL_MAKE_VERSIONED_TEST
@@ -1126,9 +1180,9 @@ namespace cereal
       struct shared_from_this_wrapper
       {
         template <class U>
-        static auto check( U const & t ) -> decltype( ::cereal::access::shared_from_this(t), std::true_type() );
+        static auto (check)( U const & t ) -> decltype( ::cereal::access::shared_from_this(t), std::true_type() );
 
-        static auto check( ... ) -> decltype( std::false_type() );
+        static auto (check)( ... ) -> decltype( std::false_type() );
 
         template <class U>
         static auto get( U const & t ) -> decltype( t.shared_from_this() );
@@ -1137,7 +1191,7 @@ namespace cereal
 
     //! Determine if T or any base class of T has inherited from std::enable_shared_from_this
     template<class T>
-    struct has_shared_from_this : decltype(detail::shared_from_this_wrapper::check(std::declval<T>()))
+    struct has_shared_from_this : decltype((detail::shared_from_this_wrapper::check)(std::declval<T>()))
     { };
 
     //! Get the type of the base class of T which inherited from std::enable_shared_from_this
@@ -1172,27 +1226,6 @@ namespace cereal
       using type = typename T::type;
     };
 
-    // ######################################################################
-    //! Member load and construct check
-    template<typename T, typename A>
-    struct has_member_load_and_construct : std::integral_constant<bool,
-      std::is_same<decltype( access::load_and_construct<T>( std::declval<A&>(), std::declval< ::cereal::construct<T>&>() ) ), void>::value>
-    { };
-
-    // ######################################################################
-    //! Non member load and construct check
-    template<typename T, typename A>
-    struct has_non_member_load_and_construct : std::integral_constant<bool,
-      std::is_same<decltype( LoadAndConstruct<T>::load_and_construct( std::declval<A&>(), std::declval< ::cereal::construct<T>&>() ) ), void>::value>
-    { };
-
-    // ######################################################################
-    //! Has either a member or non member allocate
-    template<typename T, typename A>
-    struct has_load_and_construct : std::integral_constant<bool,
-      has_member_load_and_construct<T, A>::value || has_non_member_load_and_construct<T, A>::value>
-    { };
-
     // ######################################################################
     //! Determines whether the class T can be default constructed by cereal::access
     template <class T>
@@ -1275,17 +1308,24 @@ namespace cereal
   // ######################################################################
   namespace detail
   {
-    template <class T, class A, bool Member = traits::has_member_load_and_construct<T, A>::value, bool NonMember = traits::has_non_member_load_and_construct<T, A>::value>
+    template <class T, class A,
+              bool Member = traits::has_member_load_and_construct<T, A>::value,
+              bool MemberVersioned = traits::has_member_versioned_load_and_construct<T, A>::value,
+              bool NonMember = traits::has_non_member_load_and_construct<T, A>::value,
+              bool NonMemberVersioned = traits::has_non_member_versioned_load_and_construct<T, A>::value>
     struct Construct
     {
       static_assert( cereal::traits::detail::delay_static_assert<T>::value,
-        "Cereal detected both member and non member load_and_construct functions!" );
+        "cereal found more than one compatible load_and_construct function for the provided type and archive combination. \n\n "
+        "Types must either have a member load_and_construct function or a non-member specialization of LoadAndConstruct (you may not mix these). \n "
+        "In addition, you may not mix versioned with non-versioned load_and_construct functions. \n\n " );
       static T * load_andor_construct( A & /*ar*/, construct<T> & /*construct*/ )
       { return nullptr; }
     };
 
+    // no load and construct case
     template <class T, class A>
-    struct Construct<T, A, false, false>
+    struct Construct<T, A, false, false, false, false>
     {
       static_assert( ::cereal::traits::is_default_constructible<T>::value,
                      "Trying to serialize a an object with no default constructor. \n\n "
@@ -1302,8 +1342,9 @@ namespace cereal
       { return ::cereal::access::construct<T>(); }
     };
 
+    // member non-versioned
     template <class T, class A>
-    struct Construct<T, A, true, false>
+    struct Construct<T, A, true, false, false, false>
     {
       static void load_andor_construct( A & ar, construct<T> & construct )
       {
@@ -1311,14 +1352,37 @@ namespace cereal
       }
     };
 
+    // member versioned
     template <class T, class A>
-    struct Construct<T, A, false, true>
+    struct Construct<T, A, false, true, false, false>
+    {
+      static void load_andor_construct( A & ar, construct<T> & construct )
+      {
+        const auto version = ar.template loadClassVersion<T>();
+        access::load_and_construct<T>( ar, construct, version );
+      }
+    };
+
+    // non-member non-versioned
+    template <class T, class A>
+    struct Construct<T, A, false, false, true, false>
     {
       static void load_andor_construct( A & ar, construct<T> & construct )
       {
         LoadAndConstruct<T>::load_and_construct( ar, construct );
       }
     };
+
+    // non-member versioned
+    template <class T, class A>
+    struct Construct<T, A, false, false, false, true>
+    {
+      static void load_andor_construct( A & ar, construct<T> & construct )
+      {
+        const auto version = ar.template loadClassVersion<T>();
+        LoadAndConstruct<T>::load_and_construct( ar, construct, version );
+      }
+    };
   } // namespace detail
 } // namespace cereal
 
