@@ -24,77 +24,29 @@
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-#include "common.hpp"
-#include <boost/test/unit_test.hpp>
+#define DOCTEST_CONFIG_IMPLEMENT_WITH_MAIN
+#include "bitset.hpp"
 
-template <class IArchive, class OArchive>
-void test_bitset()
-{
-  std::random_device rd;
-  std::mt19937 gen(rd());
+TEST_SUITE("bitset");
 
-  auto rng32  = [&](){ return random_binary_string<32>( gen ); };
-  auto rng65  = [&](){ return random_binary_string<65>( gen ); };
-  auto rng256 = [&](){ return random_binary_string<256>( gen ); };
-  auto rng512 = [&](){ return random_binary_string<512>( gen ); };
-
-  for(int ii=0; ii<100; ++ii)
-  {
-    std::bitset<32> o_bit32( rng32() );
-    std::bitset<65> o_bit65( rng65() );
-    std::bitset<256> o_bit256( rng256() );
-    std::bitset<512> o_bit512( rng512() );
-
-    std::ostringstream os;
-    {
-      OArchive oar(os);
-
-      oar(o_bit32);
-      oar(o_bit65);
-      oar(o_bit256);
-      oar(o_bit512);
-    }
-
-    std::bitset<32>  i_bit32;
-    std::bitset<65>  i_bit65;
-    std::bitset<256> i_bit256;
-    std::bitset<512> i_bit512;
-
-    std::istringstream is(os.str());
-    {
-      IArchive iar(is);
-
-      iar(i_bit32);
-      iar(i_bit65);
-      iar(i_bit256);
-      iar(i_bit512);
-    }
-
-    BOOST_CHECK_EQUAL( o_bit32, i_bit32 );
-    BOOST_CHECK_EQUAL( o_bit65, i_bit65 );
-    BOOST_CHECK_EQUAL( o_bit256, i_bit256 );
-    BOOST_CHECK_EQUAL( o_bit512, i_bit512 );
-  }
-}
-
-BOOST_AUTO_TEST_CASE( binary_bitset )
+TEST_CASE("binary_bitset")
 {
   test_bitset<cereal::BinaryInputArchive, cereal::BinaryOutputArchive>();
 }
 
-BOOST_AUTO_TEST_CASE( portable_binary_bitset )
+TEST_CASE("portable_binary_bitset")
 {
   test_bitset<cereal::PortableBinaryInputArchive, cereal::PortableBinaryOutputArchive>();
 }
 
-BOOST_AUTO_TEST_CASE( xml_bitset )
+TEST_CASE("xml_bitset")
 {
   test_bitset<cereal::XMLInputArchive, cereal::XMLOutputArchive>();
 }
 
-BOOST_AUTO_TEST_CASE( json_bitset )
+TEST_CASE("json_bitset")
 {
   test_bitset<cereal::JSONInputArchive, cereal::JSONOutputArchive>();
 }
 
-
+TEST_SUITE_END();
