@@ -47,7 +47,6 @@
 #include <cereal/types/complex.hpp>
 #include <cereal/types/chrono.hpp>
 #include <cereal/types/polymorphic.hpp>
-#include <cereal/types/boost_variant.hpp>
 
 #include <cereal/archives/binary.hpp>
 #include <cereal/archives/portable_binary.hpp>
@@ -56,32 +55,11 @@
 #include <limits>
 #include <random>
 
-#include <boost/version.hpp>
-#if BOOST_VERSION >= 105900
-#include <boost/test/tools/detail/print_helper.hpp>
+#include "doctest.h"
 
-namespace boost
-{
-  namespace test_tools
-  {
-    namespace tt_detail
-    {
-      template <class F, class S>
-      struct print_log_value< ::std::pair<F, S> >
-      {
-        void operator()(::std::ostream & os, ::std::pair<F, S> const & p )
-        {
-          os << "([" << p.first << "], [" << p.second << "])";
-        }
-      };
-    }
-  }
-}
-
-#endif // appropriate boost version
-
-namespace boost
+namespace std
 {
+  // Ostream overload for std::pair
   template<class F, class S> inline
   ::std::ostream & operator<<(::std::ostream & os, ::std::pair<F, S> const & p)
   {
@@ -90,6 +68,22 @@ namespace boost
   }
 }
 
+// Checks that collections have equal size and all elements are the same
+template <class T> inline
+void check_collection( T const & a, T const & b )
+{
+  auto aIter = std::begin(a);
+  auto aEnd  = std::end(a);
+  auto bIter = std::begin(b);
+  auto bEnd  = std::end(b);
+
+  CHECK_EQ( std::distance(aIter, aEnd), std::distance(bIter, bEnd) );
+
+  for( ; aIter != aEnd; ++aIter, ++bIter )
+    CHECK_EQ( *aIter, *bIter );
+}
+
+// Random Number Generation ===============================================
 template<class T> inline
 typename std::enable_if<std::is_floating_point<T>::value, T>::type
 random_value(std::mt19937 & gen)
@@ -133,6 +127,7 @@ std::string random_binary_string(std::mt19937 & gen)
   return s;
 }
 
+// Generic struct useful for testing many serialization functions
 struct StructBase
 {
   StructBase() {}
@@ -190,7 +185,7 @@ struct StructExternalSerialize : StructBase
   StructExternalSerialize(int x_, int y_) : StructBase{x_,y_} {}
 };
 
-  template<class Archive>
+template<class Archive>
 void serialize(Archive & ar, StructExternalSerialize & s)
 {
   ar(s.x, s.y);
@@ -202,19 +197,18 @@ struct StructExternalSplit : StructBase
   StructExternalSplit(int x_, int y_) : StructBase{x_,y_} {}
 };
 
-  template<class Archive> inline
+template<class Archive> inline
 void save(Archive & ar, StructExternalSplit const & s)
 {
   ar(s.x, s.y);
 }
 
-  template<class Archive> inline
+template<class Archive> inline
 void load(Archive & ar, StructExternalSplit & s)
 {
   ar(s.x, s.y);
 }
 
-
 template<class T>
 struct StructHash {
   public:
